using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[CreateAssetMenu(fileName = "ChangeDirectionCard", menuName = "GGJ21 - Pets Ex Machina/ChangeDirectionCard", order = 0)]
public class ChangeDirectionCard : CardAsset
{

    public Direction direction;

    public override Sprite CardSprite {
        get {
            if(direction == Direction.Down || direction == Direction.Up) return GameManager.Instance.generalCardData.changeDirectionVerticalCard;
            else return GameManager.Instance.generalCardData.changeDirectionHorizontalCard;
        }
    }

    public override Vector2 CardScale {
        get {
            Vector2 scale = new Vector2(1, 1);
            if(direction == Direction.Left) scale.x = -1;
            else if(direction == Direction.Down) scale.y = -1;
            return scale;
        }
    }

    public class ChangeDirectionCardBehaviour : CardBehaviour {
        public ChangeDirectionCard origin;
        public int durability;

        public ChangeDirectionCardBehaviour(ChangeDirectionCard origin, int durability){
            this.origin = origin;
            this.durability = durability;
        }

        public override CardAsset Asset => origin;

        public override void Apply(TileComponent tile, CharacterComponent character)
        {
            character.currentDirection = origin.direction;
            if(durability != 0){
                durability--;
                if(durability == 0) tile.cardBehaviour = null;
                tile.UpdateTileVisuals();
            }
        }

        public override Sprite GetSmallDecorator(){
            return GameManager.Instance.generalCardData.GetSmallDecorator(durability);
        }
    }

    public override CardBehaviour CreateBehaviour(int durability)
    {
        return new ChangeDirectionCardBehaviour(this, durability);
    }
}
