using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.EventSystems;

public enum TileType {
    Normal,
    Locked,
    Death,
    Wall
}

public class TileComponent : MonoBehaviour, IPointerEnterHandler, IPointerExitHandler, IPointerClickHandler
{
    public TileType tileType = TileType.Normal;
    [System.NonSerialized] public bool destroyed = false; 
    
    public SpriteRenderer selectionMarkerSpriteRenderer;
    public SpriteRenderer cardOverrideSpriteRenderer, cardSpriteRenderer;
    public SpriteRenderer smallDecoratorSpriteRenderer, largeDecoratorSpriteRenderer;
    public SpriteRenderer tagSpriteRenderer;

    [System.NonSerialized] public Card card;

    [System.NonSerialized] public CardAsset.CardBehaviour cardBehaviour;   
    
    public void AssignCard(Card card){
        this.card = card;
        cardBehaviour = card.asset.CreateBehaviour(card.durability);
    }

    public void ClearCard(){
        this.card = null;
        cardBehaviour = null;
    }

    public void UpdateTileVisuals(){
        if(destroyed){
            gameObject.SetActive(false);
        } else {
            gameObject.SetActive(true);
            if(cardBehaviour != null){
                cardOverrideSpriteRenderer.gameObject.SetActive(!GameManager.Instance.IsRunning);
                cardSpriteRenderer.sprite = cardBehaviour.Asset.CardSprite;
                Vector3 scale = cardBehaviour.Asset.CardScale;
                scale.z = 1;
                cardSpriteRenderer.transform.localScale = scale;
                smallDecoratorSpriteRenderer.sprite = cardBehaviour.GetSmallDecorator();
                largeDecoratorSpriteRenderer.sprite = cardBehaviour.Asset.LargeDecoratorSprite;
                tagSpriteRenderer.sprite = cardBehaviour.Asset.TagSprite;
            } else {
                cardOverrideSpriteRenderer.gameObject.SetActive(false);
                cardSpriteRenderer.sprite = null;
                cardSpriteRenderer.transform.localScale = Vector3.one;
                smallDecoratorSpriteRenderer.sprite = null;
                largeDecoratorSpriteRenderer.sprite = null;
                tagSpriteRenderer.sprite = null;
            }
        }
    }

    void Start()
    {
        selectionMarkerSpriteRenderer.gameObject.SetActive(false);
    }

    public void OnPointerEnter(PointerEventData eventData)
    {
        if(tileType == TileType.Normal) selectionMarkerSpriteRenderer.gameObject.SetActive(true);
    }

    public void OnPointerExit(PointerEventData eventData)
    {
        selectionMarkerSpriteRenderer.gameObject.SetActive(false);
    }

    public void OnPointerClick(PointerEventData eventData)
    {
        if(!GameManager.Instance.IsRunning && tileType == TileType.Normal){
            if(eventData.button == PointerEventData.InputButton.Left){
                GameManager.Instance.PutCardOnTile(this);
            } else if(eventData.button == PointerEventData.InputButton.Right){
                GameManager.Instance.ClearCardOnTile(this);
            }
        }
    }
}
