using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.EventSystems;
using UnityEngine.UI;

public class TileUIComponent : MonoBehaviour, IPointerEnterHandler, IPointerExitHandler, IPointerClickHandler
{

    public RectTransform cardGroup;
    public Image selectionMarkerImage, cardImage;
    public Image smallDecoratorImage, largeDecoratorImage;
    public Image tagImage;
    [System.NonSerialized] public Card card;
    
    void Start()
    {
        selectionMarkerImage.gameObject.SetActive(false);
    }

    public void AssignCard(Card card){
        this.card = card;
        cardImage.sprite = card.asset.CardSprite;
        Vector3 scale = card.asset.CardScale;
        scale.z = 1;
        cardImage.rectTransform.localScale = scale;
        smallDecoratorImage.sprite = GameManager.Instance.generalCardData.GetSmallDecorator(card.durability);

        Sprite sprite = card.asset.LargeDecoratorSprite;
        if(sprite != null){
            largeDecoratorImage.gameObject.SetActive(true);
            largeDecoratorImage.sprite = sprite;
        } else {
            largeDecoratorImage.gameObject.SetActive(false);
        }

        sprite = card.asset.TagSprite;
        if(sprite != null){
            tagImage.gameObject.SetActive(true);
            tagImage.sprite = sprite;
        } else {
            tagImage.gameObject.SetActive(false);
        }
    }

    public void OnPointerEnter(PointerEventData eventData)
    {
        if(!GameManager.Instance.IsRunning) selectionMarkerImage.gameObject.SetActive(true);
    }

    public void OnPointerExit(PointerEventData eventData)
    {
        selectionMarkerImage.gameObject.SetActive(false);
    }

    public void OnPointerClick(PointerEventData eventData)
    {
        if(!GameManager.Instance.IsRunning){
            if(eventData.button == PointerEventData.InputButton.Left){
                GameManager.Instance.SelectTileFromHand(this);
            }
        }
    }
}
